@@ -85,6 +85,7 @@ void GLWidget::keyReleaseEvent(QKeyEvent *event) {
 
 
 GLWidget::GLWidget(QMainWindow *parent) : QGLWidget(parent) {
+	isAlussa = true;
 	qDBusInterface = new QDBusInterface(MCE_SERVICE, MCE_REQUEST_PATH, 
 			MCE_REQUEST_IF, dBusConnection, this);	
 	dBusConnection.connect(MCE_SERVICE, MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
@@ -109,9 +110,11 @@ GLWidget::GLWidget(QMainWindow *parent) : QGLWidget(parent) {
 	quitButton->hide();
 	showQuitButton = false;	
 	connect(quitButton, SIGNAL(clicked()), this, SLOT(hideGame()));		
+	
 }
 
 void GLWidget::newGame() {
+	isAlussa = false;
 	keskeytetty = true;	
 	showQuitButton = false;
 	quitButton->hide();
@@ -563,10 +566,10 @@ void GLWidget::displayStateChanged(const QDBusMessage &message) {
 void GLWidget::setDisplayState(const QString &state) {
 	if(!state.isEmpty()) {
 		if(state == MCE_DISPLAY_ON_STRING) {
-			if(keskeytetty) resumeGame();
+			if(!isAlussa) resumeGame();
 		}
 		else if(state == MCE_DISPLAY_OFF_STRING) {
-			if(!isHidden()) pauseGame();
+			pauseGame();
 		}
 	}
 }
@@ -589,7 +592,7 @@ bool GLWidget::event(QEvent *event) {
 		if(!this->isHidden()) pauseGame();
 	}
 	else if(event->type() == QEvent::Enter) {
-		if(!this->isHidden()) resumeGame();
+		resumeGame();
 	}
 	return QGLWidget::event(event);
 }
